package com.zbsz.controller;

import com.common.info.CodeMsg;
import com.zbsz.entity.User;
import com.zbsz.info.LoginInfo;
import com.zbsz.info.Result;
import com.zbsz.service.UserService;
import com.zbsz.tool.JwtTool;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.validation.Valid;

@Slf4j
@RestController
@RequestMapping("/auth")
@Api(tags = "服务接口")
public class AuthController {
    @Resource
    private UserService userService;

    /**
     * 登录表单需要校验字段是否含有 or 1=1
     * @param info
     * @return
     */
    @ApiOperation(value = "登录",notes = "登录服务")
    @PostMapping("login")
    public Result login(@Valid LoginInfo info) {
        Result result = new Result();
        try {
            User user = userService.lambdaQuery().eq(User::getName,info.getUserName()).eq(User::getPassWord,info.getPassWord()).one();
            if(user!=null){
                result.setCode(CodeMsg.SUCCESS.getCode());
                result.setMsg(CodeMsg.SUCCESS.getMessage());
            }else {
                result.setCode(CodeMsg.AUTH_FAILURE.getCode());
                result.setMsg(CodeMsg.AUTH_FAILURE.getMessage());
                result.setData(JwtTool.getToken(info.getUserName()));
            }
        }catch (Exception e){
            log.error("-------- AuthController login 异常 : "+e.getMessage(),e);
            result.setCode(CodeMsg.FAILURE.getCode());
            result.setMsg(e.getMessage());
        }
        return result;
    }
}
